@@ -68,6 +68,9 @@ private slots:
     //! Invoked when the dialer widget call button is clicked
     void dialNow (const QString &strTarget);
 
+    //! Invoked by the DBus Text server without any text data
+    void onSendTextWithoutData (const QStringList &arrNumbers);
+
     void onDialDlgClose (int retval, const QString &strNumber);
     //! Invoked when dialing has started
     void dialInProgress (const QString &strNumber);
@@ -109,6 +112,7 @@ private slots:
     //! Invoked by GVAccess when the voice mail download has completed
     void onVmailDownloaded (bool bOk, const QVariantList &arrParams);
 
+    //! Invoked by QML when the user selects a new phone method
     void onRegPhoneSelectionChange (int index);
 
 private:
@@ -124,6 +128,8 @@ private:
                       const QString &strNameLink,
                       GVContactInfo &info);
 
+    bool findInfo (const QString &strNumber, GVContactInfo &info);
+
     void closeEvent (QCloseEvent *event);
 
     bool refreshRegisteredNumbers ();
